import '../vwc-dialog.js';
import {
	waitNextTask,
	textToDomToParent,
	isolatedElementsCreation,
} from '../../../test/test-helpers.js';
import { chaiDomDiff } from '@open-wc/semantic-dom-diff';

chai.use(chaiDomDiff);

const COMPONENT_NAME = 'vwc-dialog';

describe('Dialog', () => {
	let addElement = isolatedElementsCreation();

	it(`${COMPONENT_NAME} is defined as a custom element`, async () => {
		assert.exists(customElements.get(COMPONENT_NAME));
	});

	it('should internal contents', async () => {
		const addedElements = addElement(
			textToDomToParent(`<${COMPONENT_NAME}>Button Text</${COMPONENT_NAME}>`)
		);
		const actualElement = addedElements[0];
		await waitNextTask();
		expect(actualElement.shadowRoot.innerHTML)
			.to
			.equalSnapshot();
	});

	it(`should hide the actions section`, async function () {
		const [actualElement] = addElement(
			textToDomToParent(`<${COMPONENT_NAME}>Button Text</${COMPONENT_NAME}>`)
		);
		actualElement.hideActions = true;
		await actualElement.updateComplete;
		expect(actualElement.shadowRoot.querySelector('#content')
			.classList
			.contains('last'))
			.to
			.equal(true);
	});

	it(`should close when clicking the dismiss button`, async function () {
		const [actualElement] = addElement(
			textToDomToParent(`<${COMPONENT_NAME} open>Button Text</${COMPONENT_NAME}>`)
		);
		await actualElement.updateComplete;

		const dismissButton = actualElement.shadowRoot.querySelector('.dismiss-button');

		dismissButton.click();

		expect(actualElement.open)
			.to
			.equal(false);
	});
});
